//////////////////////////////////////////////////////////////////////////
// Copyright 2002-2006 Aspose Pty Ltd. All Rights Reserved.
//
// This file is part of Aspose.Words. The source code in this file
// is only intended as a supplement to the documentation, and is provided
// "as is", without warranty of any kind, either expressed or implied.
//////////////////////////////////////////////////////////////////////////

package com.aspose.words.demos;

import com.aspose.words.License;
import com.aspose.words.Document;

import java.io.File;

/**
 * Launches the demo-classes sequentially in batch mode using simple main() method.
 */
public class DemoBatch
{
	public static void main(String[] args) throws Exception
	{
		//init the demo
		Demo.initDemo();
		loadLicence();

		//launch all demos sequentally
		Demo demo = new AlternatingRowsDemo();
		generateDemoFile(demo);

		demo = new DinnerInvitationDemo();
		generateDemoFile(demo);

		demo = new DocumentBuilderDemo();
		generateDemoFile(demo);

		demo = new EmployeesReportDemo();
		generateDemoFile(demo);

		demo = new MailingLabelsDemo();
		generateDemoFile(demo);

		demo = new ProductCatalogDemo();
		generateDemoFile(demo);

		demo = new SalesInvoiceDemo();
		generateDemoFile(demo);

		demo = new StampAndWatermarkDemo();
		generateDemoFile(demo);

		//close the demo
		Demo.closeDB();
	}

	private static void loadLicence() throws Exception
	{
		File licenseFile = new File(Demo.getRootDistributiveDir(), "Aspose.Words.Java.lic");
		if (licenseFile.exists())
		{
			//This shows how to license Aspose.Words.
			//If you don't specify a license, Aspose.Words works in evaluation mode.
			License license = new License();
			license.setLicense(licenseFile.getAbsolutePath());
		}
	}

	private static void generateDemoFile(Demo demo) throws Exception
	{
		try
		{
			System.out.println("\n\r Executing " + demo.getDemoName() +
							   " using template document " + demo.getPathToTemplateDoc());

			Document doc = demo.execute();

			System.out.println("\tgenerating document in DOC format: " + demo.getPathToGeneratedDoc());
			doc.save(demo.getPathToGeneratedDoc());

			System.out.println("\tgenerating document in HTML format: " + demo.getPathToGeneratedHtml());
			doc.save(demo.getPathToGeneratedHtml());

			System.out.println("\tgenerating document in DOCX format: " + demo.getPathToGeneratedDocx());
			doc.save(demo.getPathToGeneratedDocx());

			System.out.println("\tgenerating document in TXT format: " + demo.getPathToGeneratedTxt());
			doc.save(demo.getPathToGeneratedTxt());
		}
		catch (Exception e)
		{
			e.printStackTrace();
		}

	}
}
