//////////////////////////////////////////////////////////////////////////
// Copyright 2002-2006 Aspose Pty Ltd. All Rights Reserved.
//
// This file is part of Aspose.Words. The source code in this file
// is only intended as a supplement to the documentation, and is provided
// "as is", without warranty of any kind, either expressed or implied.
//////////////////////////////////////////////////////////////////////////
package com.aspose.words.demos;

import com.aspose.words.Document;
import com.aspose.words.DocumentBuilder;
import com.aspose.words.MergeFieldEventArgs;
import com.aspose.words.MergeFieldEventHandler;

import java.awt.*;
import java.sql.ResultSet;

/**
 * Creates a list of products with alternating table row colors. Shows how to use DocumentBuilder
 * inside mail merge event handler.
 */
public class AlternatingRowsDemo extends Demo implements MergeFieldEventHandler
{
	public AlternatingRowsDemo()
	{
		init("AlternatingRowsDemo");
	}

	public Document execute() throws Exception
    {
        //Open the template document
        Document doc = new Document(getPathToTemplateDoc());//JAVA-changed

        //Attach an event handler to be called for each merge field.
        doc.getMailMerge().addMergeFieldEventHandler(this);

        //Need document builder and row counter during mail merge, they are used in the event handler.
        mBuilder = new DocumentBuilder(doc);
        mRowIdx = 1;	//There is one header row, don't color it.

        //Execute the mail merge.
        ResultSet suppliers = executeQuery("SELECT TOP 10 * FROM Suppliers");
        doc.getMailMerge().executeWithRegions("Suppliers", suppliers);

		return doc;
    }

    /**
     * Called for every merge field encountered in the document.
     * We can either return some data to the mail merge engine or do something
     * else with the document. In this case we choose to modify cell formatting.
     */
    public void mergeField(Object object, MergeFieldEventArgs e) throws Exception
    {
        //This way we catch the beginning of a new row.
        if ("CompanyName".equals(e.getFieldName()))
        {
            //Select the color depending on whether the row number is even or odd.
            Color rowColor = ((mRowIdx & 0x01) != 0) ? new Color(240, 255, 255) : new Color(255, 235, 205);
            //There is no way to set cell properties for the whole row at the moment,
            //so we have to iterate over all cells in the row.
            for (int colIdx = 0; colIdx < 4; colIdx++)
            {
                mBuilder.moveToCell(0, mRowIdx, colIdx, 0);
                mBuilder.getCellFormat().getShading().setBackgroundPatternColor(rowColor);
            }
            //This is somewhat a hack because right now document builder points to a merge field
            //and Aspose.Words will replace the field with data leaving document builder cursor dangling.
            mBuilder.moveToDocumentStart();
            mRowIdx++;
        }
    }

    private int mRowIdx;
    private DocumentBuilder mBuilder;
}
