//////////////////////////////////////////////////////////////////////////
// Copyright 2002-2006 Aspose Pty Ltd. All Rights Reserved.
//
// This file is part of Aspose.Words. The source code in this file
// is only intended as a supplement to the documentation, and is provided
// "as is", without warranty of any kind, either expressed or implied.
//////////////////////////////////////////////////////////////////////////
package com.aspose.words.demos;

import com.aspose.words.Document;

import java.sql.ResultSet;

/**
 * Prints company names and addresses on mailing labels. Shows how to use NEXT field and how to
 * merge from DataReader.
 */
public class MailingLabelsDemo extends Demo
{
	public MailingLabelsDemo()
	{
		init("MailingLabelsDemo");
	}

    public Document execute() throws Exception
    {
        //Open the template document
		Document doc = new Document(getPathToTemplateDoc());//JAVA-changed

        //*** Use of NEXT field
        //
        //Note that each mailing label in the document has NEXT field which causes
        //Aspose.Words mail merge engine to retrieve the next record from the data source.
        //When Aspose.Words reaches the end of the document, it repeats the whole document
        //exactly as it does during normal mail merge, thus creating another sheet of labels.
        //
        //Note that NEXT fields are not visible in MS Word unless display of field codes is turned on.
        //To switch between viewing field codes or field results, press Alt+F9 in MS Word.

        //Mail merge customer details from the table to the document.
        ResultSet customers = executeQuery("SELECT TOP 50 * FROM Customers ORDER BY Country, CompanyName;");
        doc.getMailMerge().execute(customers);

        //This is useful if you want to delete any merge fields that might be left at the end of the document.
        doc.getMailMerge().deleteFields();

		return doc;
    }
}
