//////////////////////////////////////////////////////////////////////////
// Copyright 2002-2006 Aspose Pty Ltd. All Rights Reserved.
//
// This file is part of Aspose.Words. The source code in this file
// is only intended as a supplement to the documentation, and is provided
// "as is", without warranty of any kind, either expressed or implied.
//////////////////////////////////////////////////////////////////////////
package com.aspose.words.demos;

import com.aspose.words.Document;

import java.sql.ResultSet;

/**
 * Creates an invoice with order header, details and summary. Shows how to mail merge data from
 * multiple tables, format date and numeric fields and use merge regions to grow portions of the document.
 */
public class SalesInvoiceDemo extends Demo
{
	public SalesInvoiceDemo()
	{
		init("SalesInvoiceDemo");
	}

    public Document execute() throws Exception
    {
        //Open the template document
		Document doc = new Document(getPathToTemplateDoc());//JAVA-changed

        //*** Mail Merge Regions
        //
        //Using mail merge regions allows you to repeat a portion of the document for each
        //record in your data source. The most common use for a mail merge region is to grow
        //a table inside a document.
        //
        //Note that mail merge region is a new concept introduced in Aspose.Words and not
        //available in the classic MS Word mail merge.
        //
        //To create a mail merge region inside a document, you need to insert two merge fields
        //with special names TableStart:[TableName] and TableEnd:[TableName] that designate
        //the beginning and end of the mail merge region. Aspose.Words mail merge engine repeats
        //the document content enclosed inside the region for every record in your data source.
        //
        //In this demo, the document contains a table which consists of only two rows:
        //one header and one data row. TableStart:OrderDetails and TableEnd:OrderDetails merge fields
        //that designate the merge region are inserted into the table row along with other merge fields.

        //*** Master-Child Data on the Report
        //
        //Note that documents such as invoice might contain data with master-child relationships,
        //for example Order and OrderDetails. The easiest and most natural way to build such a report
        //would be to use nested merge regions, but this is not yet directly supported by Aspose.Words.
        //
        //This demo is designed to produce one invoice at a time and avoids using master-child
        //relationship in the report.
        //
        //However, it is still possible to create reports with master-child data using Aspose.Words
        //with some workarounds. See ProductCatalogDemo for information on how to create reports with
        //master-child data.

        //*** Date and Number Formatting in Merge Fields
        //
        //You can either format your data in the query or specify formatting flags in the merge fields
        //in the document.
        //
        //Merge fields with date or number formatting flags look like this:
        //MERGEFIELD  OrderDate \@ "dd-MMM-yyyy"
        //MERGEFIELD  UnitPrice \# "$#,##0.00"
        //
        //You can switch display of field codes on/off in MS Word using Alt+F9 to see which
        //fields in this demo use formatting flags.

        //Perform several mail merge operations populating only part of the document each time.
        doc.getMailMerge().executeWithRegions("Orders", getTestOrder());
        doc.getMailMerge().executeWithRegions("OrderTotals", getTestOrderTotals());
        doc.getMailMerge().executeWithRegions("OrderDetails", getTestOrderDetails());

		return doc;
	}

    private ResultSet getTestOrder() throws Exception
    {
        return executeQuery(
            "SELECT * FROM AsposeWordOrders WHERE OrderId = " + TestOrderId);
    }

    private ResultSet getTestOrderDetails() throws Exception
    {
        return executeQuery(
            "SELECT * FROM AsposeWordOrderDetails WHERE OrderId = " + TestOrderId + " ORDER BY ProductID" );
    }

    private ResultSet getTestOrderTotals() throws Exception
    {
        return executeQuery(
            "SELECT * FROM AsposeWordOrderTotals WHERE OrderId = " + TestOrderId);
    }

    private final int TestOrderId = 10444;

}
