//////////////////////////////////////////////////////////////////////////
// Copyright 2002-2006 Aspose Pty Ltd. All Rights Reserved.
//
// This file is part of Aspose.Words. The source code in this file
// is only intended as a supplement to the documentation, and is provided
// "as is", without warranty of any kind, either expressed or implied.
//////////////////////////////////////////////////////////////////////////

package com.aspose.words.demos;

import com.aspose.words.*;

import java.io.File;
import java.util.Date;

/**
 * Opens an existing document and inserts a watermark image and a footer with some information
 * to indicate the document was processed by the system.
 */
public class StampAndWatermarkDemo extends Demo
{
	public StampAndWatermarkDemo()
	{
		init("StampAndWatermarkDemo");
	}

	public Document execute() throws Exception
	{
		//Open the template document
		Document doc = new Document(getPathToTemplateDoc());//JAVA-changed

		//Create a document builder that will allow us to modify the document.
		DocumentBuilder builder = new DocumentBuilder(doc);

		//The cursor is in the first section already, navigate to the header as this is where
		//we want to insert the watermark.
		builder.moveToHeaderFooter(HeaderFooterType.HEADER_PRIMARY);

		//Insert a floating picture.
		Shape shape = builder.insertImage(new File(mDocumentsDir, "Aspose.Logo.gif").getAbsolutePath());
		shape.setWrapType(WrapType.NONE);
		shape.setBehindText(true);

		// Position the image in the center of the page.
		shape.setRelativeHorizontalPosition(RelativeHorizontalPosition.PAGE);
		shape.setHorizontalAlignment(HorizontalAlignment.CENTER);
		shape.setRelativeVerticalPosition(RelativeVerticalPosition.PAGE);
		shape.setVerticalAlignment(VerticalAlignment.CENTER);

		//Insert a table with other office information in the footer.
		builder.moveToHeaderFooter(HeaderFooterType.FOOTER_PRIMARY);

		Border topBorder = builder.getCellFormat().getBorders().getByBorderType(BorderType.TOP);
		topBorder.setLineStyle(LineStyle.SINGLE);
		topBorder.setLineWidth(1);

		builder.insertCell();
		builder.getCellFormat().setWidth(3 * 72);
		builder.write("Processed on: " + new Date().toString());

		builder.insertCell();
		builder.getParagraphFormat().setAlignment(ParagraphAlignment.RIGHT);
		builder.write("Version 1.00");

		builder.endRow();
		builder.endTable();

		return doc;
	}
}
