/**
 * Copyright Aspose.com, 2006
 * Helper Java code to port Aspose.Word C# source, Sep 19, 2006 
 *
 * @author Konstantin Sidorenko
 */

package com.aspose.words.documentexplorer;

import javax.swing.*;
import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeEvent;
import java.io.File;

/**
 * Corrects JFileChooser Save Dialog behaviour about like MS Word do.
 */
class SaveDialogChangeListener implements PropertyChangeListener
{
	public SaveDialogChangeListener(JFileChooser chooser)
	{
		mChooser = chooser;
	}

	public void propertyChange(PropertyChangeEvent e)
	{
		String propertyName = e.getPropertyName();

		if (JFileChooser.SELECTED_FILE_CHANGED_PROPERTY.equals(propertyName))
			fileChanged(e);

		else if (JFileChooser.FILE_FILTER_CHANGED_PROPERTY.equals(propertyName))
			filterChanged(e);

		else if (JFileChooser.DIRECTORY_CHANGED_PROPERTY.equals(propertyName))
			directoryChanged(e);

	}

	/**
	 * Remembers old and new files for the listener subsequent using.
	 */
	private void fileChanged(PropertyChangeEvent e)
	{
		mNewFile = (File) e.getNewValue();
		mOldFile = (File) e.getOldValue();
	}

	/**
	 * Changes a file extension when an user changes a file filter.
	 */
	private void filterChanged(PropertyChangeEvent e)
	{
		//when an user changes a filter, JFileChooser deletes "old" file name - correct this.
		if (mNewFile == null && mOldFile != null)
		{
			mNewFile = mOldFile;
		}

		//change a file extension according to the new filter.
		SaveFileFilter newFilter = (SaveFileFilter) e.getNewValue();
		mNewFile = Utils.setExtension(mNewFile, newFilter.mExtension);

		//show this to the user
		mChooser.setSelectedFile(mNewFile);
		mChooser.updateUI();
	}

	/**
	 * Restores a file name deleted by JFileChooser when an user changes current directory.
	 */
	private void directoryChanged(PropertyChangeEvent e)
	{
		if (mNewFile == null && mOldFile != null)
		{
			mNewFile = new File(mOldFile.getName());

			mChooser.setSelectedFile(mNewFile);
			mChooser.updateUI();
		}
	}

	private static JFileChooser mChooser;
	private static File mNewFile;
	private static File mOldFile;
}
